@@ -42,7 +42,7 @@ DEFAULT_SPECD_PATH = os.path.join(
     os.path.dirname(__file__), "../../gosdk/specs/"
 )
 
-VERSION = "0.9.7"
+VERSION = "0.9.10"
 COPYRIGHT = "Copyright: GenomOncology, LLC"
 
 
@@ -320,11 +320,23 @@ def load_hotspots(state, data_set="DATASET", data_set_version="DSV"):
     help="Include homozygous reference and unknown calls.",
     is_flag=True,
 )
+@click.option(
+    "--filter_file",
+    "-ff",
+    help="Annotations filter file",
+    type=str,
+    default=None,
+)
 @options.size_option
 @options.build_option
 @options.pass_state
 def annotate_calls(
-    state, fields, run_async, delete_if_exists, keep_ref_unknown_calls
+    state,
+    fields,
+    run_async,
+    delete_if_exists,
+    keep_ref_unknown_calls,
+    filter_file,
 ):
     """Get annotations for stream of calls."""
     if run_async:
@@ -334,6 +346,18 @@ def annotate_calls(
         create_function = kms.create_sync_processor
         sdk_function = kms.annotations.sync_annotate
 
+    filter_anns = (
+        [ann for ann in list(sources.AnnotationsFilterFileSource(filter_file))]
+        if filter_file is not None
+        else None
+    )
+
+    # get the annotation bundle version once instead of once per batch
+    sdk = state.create_sdk(async_enabled=False)
+    annotation_bundle_version = kms.annotations.get_annotation_bundle_version(
+        sdk
+    )
+
     return [
         filter(is_not_skipped_call),
         filter(
@@ -350,6 +374,8 @@ def annotate_calls(
             fields=fields,
             delete_if_exists=delete_if_exists,
             build=state.build,
+            filter_anns=filter_anns,
+            annotation_bundle_version=annotation_bundle_version,
         ),
         concat,
     ]
@@ -412,14 +438,15 @@ def to_tsv(column, include_header):
 
 
 @gocli.command()
+@click.option("--header_file_path", "-hfp", type=str)
 @click.option(
     "--historical", "-h", help="Write annotations to VCF.", is_flag=True
 )
-def to_vcf(historical):
+def to_vcf(header_file_path, historical):
     """Render calls to VCF file format."""
     if historical:
-        return [sinks.HistoricalVcfFileSink()]
-    return [sinks.VcfFileSink()]
+        return [sinks.HistoricalVcfFileSink(header_file_path=header_file_path)]
+    return [sinks.VcfFileSink(header_file_path=header_file_path)]
 
 
 @gocli.command()
@@ -628,7 +655,7 @@ def load_features(state, workers):
 @options.size_option
 @options.build_option
 @options.pass_state
-def load_annotations(state, data_set, data_set_version, workers):
+def load_annotations(state, timeout, data_set, data_set_version, workers):
     """Loads variant objects into annotations core."""
     return [
         filter(is_not_skipped_call),
