@@ -37,12 +37,16 @@ EXCLUDE_BUILD_FIELDS = ["is_gene_annotation"]
 
 @curry
 async def async_annotate(
-    data, sdk=None, fields=None, delete_if_exists=False, build=GRCh37
+    data,
+    sdk=None,
+    fields=None,
+    delete_if_exists=False,
+    build=GRCh37,
+    filter_anns=None,
+    annotation_bundle_version=None,
 ):
     csra_batch = convert_to_csra([{**d, "build": build} for d in data])
 
-    annotation_bundle_version = await get_annotation_bundle_version_async(sdk)
-
     if csra_batch:
         annotations_list = await sdk.call_with_retry(
             sdk.annotations.post_annotations,
@@ -54,7 +58,11 @@ async def async_annotate(
         annotations_list = None
 
     annotated_calls = annotate_calls(
-        annotations_list, data, fields, annotation_bundle_version
+        annotations_list,
+        data,
+        fields,
+        annotation_bundle_version,
+        filter_anns=filter_anns,
     )
 
     logger.get_logger().debug(
@@ -71,12 +79,16 @@ async def async_annotate(
 
 @curry
 def sync_annotate(
-    data, sdk=None, fields=None, delete_if_exists=False, build=GRCh37
+    data,
+    sdk=None,
+    fields=None,
+    delete_if_exists=False,
+    build=GRCh37,
+    filter_anns=None,
+    annotation_bundle_version=None,
 ):
     csra_batch = convert_to_csra([{**d, "build": build} for d in data])
 
-    annotation_bundle_version = get_annotation_bundle_version(sdk)
-
     annotations_list = (
         sdk.call_with_retry(
             sdk.annotations.post_annotations,
@@ -89,7 +101,11 @@ def sync_annotate(
     )
 
     annotated_calls = annotate_calls(
-        annotations_list, data, fields, annotation_bundle_version
+        annotations_list,
+        data,
+        fields,
+        annotation_bundle_version,
+        filter_anns=filter_anns,
     )
 
     logger.get_logger().debug(
@@ -219,11 +235,17 @@ def annotate_hotspots(data):
     return annotations
 
 
-def annotate_calls(annotations_list, data, fields, annotation_bundle_version):
+def annotate_calls(
+    annotations_list, data, fields, annotation_bundle_version, filter_anns=None
+):
     # todo: determine if it makes sense to not return all annotations....
     fields = None  # resolve_fields(fields)
     func = partial(
-        add_annotation, annotations_list, fields, annotation_bundle_version
+        add_annotation,
+        annotations_list,
+        fields,
+        annotation_bundle_version,
+        filter_anns=filter_anns,
     )
     annotated_calls = list(map(func, data))
     return annotated_calls
@@ -234,7 +256,8 @@ def add_annotation(
     fields,
     expected_bundle_version,
     call: dict,
-):
+    filter_anns=None,
+):  # pragma: no mccabe
 
     if annotations_list and is_call_or_variant(call):
         csra = to_csra(call)
@@ -263,6 +286,12 @@ def add_annotation(
                 )
                 raise AnnBundleVersionAssertionError(msg)
 
+        # filter the annotations if there was a filter file passed in
+        if filter_anns is not None and isinstance(filter_anns, list):
+            annotations = handle_filtering_annotations(
+                annotations, filter_anns
+            )
+
         call["annotations"] = annotations
         call[__TYPE__] = f"ANNOTATED_{call.get(__TYPE__, 'CALL')}"
 
@@ -272,6 +301,25 @@ def add_annotation(
     return call
 
 
+def handle_filtering_annotations(annotations, filter_anns):
+    gene_annotations = []
+    for gene_ann in annotations.get("gene_annotations", []):
+        gene_ann_filtered = {
+            k: v
+            for k, v in gene_ann.items()
+            if k in filter_anns or k == "gene"
+        }
+        if len(gene_ann_filtered) > 0:
+            gene_annotations.append(gene_ann_filtered)
+    annotations["gene_annotations"] = gene_annotations
+    annotations = {
+        k: v
+        for k, v in annotations.items()
+        if k in filter_anns or k == "gene_annotations"
+    }
+    return annotations
+
+
 def up_build(call: dict):
     hgvs_g = call.get("hgvs_g")
     build = call.get("build")
@@ -346,6 +394,7 @@ ANNOTATIONS = [
     "representations",
     "hgvs_g",
     "alteration",
+    "gene_annotations",
 ]
 
 ANNOTATIONS_SET = set(ANNOTATIONS)
