@@ -35,6 +35,7 @@ class DocType(Enum):
     # Annotation Data Sets
     GNOMAD = "GNOMAD"
     HGMD = "HGMD"
+    HGMD_GENE_LIST = "HGMD_GENE_LIST"
     BAYLOR_WGL = "BAYLOR_WGL"
     DBNSFP = "DBNSFP"
     CLINVAR = "CLINVAR"
@@ -52,6 +53,7 @@ class DocType(Enum):
     UNIPROT_DOMAIN = "UNIPROT_DOMAIN"
     UNIPROT = "UNIPROT"
     MITOMAP = "MITOMAP"
+    PLI = "PLI"
     GENE_TYPE = "GENE_TYPE"
 
     def is_a(self, a_dict):
@@ -120,6 +122,10 @@ def is_not_skipped_call(doc):
     return DocType.SKIPPED_CALL.is_not(doc)
 
 
+def is_header(doc):
+    return DocType.HEADER.is_not(doc)
+
+
 @curry
 def filter_out_ref_unknown(doc, keep_ref_unknown_calls=False):
     if not keep_ref_unknown_calls:
