@@ -1,5 +1,5 @@
 from click.utils import LazyFile
-from cytoolz.curried import curry, dissoc
+from cytoolz.curried import curry
 
 from genomoncology.pipeline.converters import to_json_str
 
