@@ -7,6 +7,7 @@ from .aggregated import AggregatedCOSMICSources, AggregatedFileSource
 from .maf import MAFSource
 from .xml import XMLSource
 from . import one_off_sources
+from .annotations_filter import AnnotationsFilterFileSource
 
 __all__ = (
     "Source",
@@ -21,6 +22,7 @@ __all__ = (
     "AggregatedFileSource",
     "MAFSource",
     "XMLSource",
+    "AnnotationsFilterFileSource",
 )
 
 
