@@ -25,19 +25,19 @@ class MitomapFileSource(LazyFileSource):
 
         self.dump_file = open(dump_file_name, "r")
         self.table_names = [
-            "genbank",
-            "gbcontrol",
-            "genbank_count",
-            "genbank_haplogroup",
-            "mitotip",
-            "gbcontrol",
+            "mitomap.genbank",
+            "mitomap.gbcontrol",
+            "mitomap.genbank_count",
+            "mitomap.genbank_haplogroup",
+            "mitomap.mitotip",
+            "mitomap.gbcontrol",
         ]
         self.table_indexed_fields = {
-            "genbank": ["tpos", "qnt"],
-            "gbcontrol": ["tpos", "qnt"],
-            "genbank_count": ["haplogroup", "alt", "pos"],
-            "genbank_haplogroup": ["haplogroup"],
-            "mitotip": ["pos", "ref", "alt"],
+            "mitomap.genbank": ["tpos", "qnt"],
+            "mitomap.gbcontrol": ["tpos", "qnt"],
+            "mitomap.genbank_count": ["haplogroup", "alt", "pos"],
+            "mitomap.genbank_haplogroup": ["haplogroup"],
+            "mitomap.mitotip": ["pos", "ref", "alt"],
         }
         self.lines = self.dump_file.readlines()
         self.table_line_boundaries = {}
@@ -197,7 +197,7 @@ class MitomapFileSource(LazyFileSource):
             line = line.replace("\n", "")
             record = line.split("\t")
             # get the pos, ref, and alt to see if duplicate hgvs
-            gb_fields = self.table_fields["genbank"]
+            gb_fields = self.table_fields["mitomap.genbank"]
             pos = record[gb_fields.index("tpos")]
             ref = record[gb_fields.index("tnt")]
             alt = record[gb_fields.index("qnt")]
@@ -235,10 +235,12 @@ class MitomapFileSource(LazyFileSource):
     def create_and_populate_table(
         self, table_name, the_lines, fields, indexed_fields
     ):
-        if table_name == "genbank":
+        if table_name == "mitomap.genbank":
             data = self.parse_and_set_genbank_data(the_lines)
         else:
             data = self.set_table_data(the_lines)
+        # remove mitomap. from the name when actually creating the db table
+        table_name = table_name.replace("mitomap.", "")
         self.create_table(table_name, fields)
         self.insert_into_table(table_name, fields, data, indexed_fields)
 
