@@ -3,6 +3,7 @@ from . import (
     dbnsfp,
     gnomad,
     hgmd,
+    hgmd_gene_list,
     markers,
     clinvar,
     thousandgenomes,
@@ -20,6 +21,7 @@ from . import (
     uniprot,
     mitomap,
     gene_type,
+    pli,
 )
 
 __all__ = (
@@ -27,6 +29,7 @@ __all__ = (
     "dbnsfp",
     "gnomad",
     "hgmd",
+    "hgmd_gene_list",
     "markers",
     "clinvar",
     "thousandgenomes",
@@ -45,4 +48,5 @@ __all__ = (
     "uniprot",
     "mitomap",
     "gene_type",
+    "pli",
 )
