@@ -16,7 +16,8 @@ NAME_MAPPING = {
     "tissues__mstring": "TISSUES",
     "tissue_frequency__mstring": "TISSUES_FREQ",
     "resistance_mutation__mstring": "RESISTANCE_MUTATION",
-    "ID__mstring": "ID",
+    "ID__mstring": "MUTATION_ID",
+    "genomicID__mstring": "ID",
     "CDS__mstring": "CDS",
     "AA__mstring": "AA",
     "legacy_id__mstring": "LEGACY_ID",
@@ -50,7 +51,7 @@ def dict_list_to_key_value_list(x, field):
 
 
 def clean_gene(x):
-    # remove dups and remove everything after "_ENST"
+    # remove everything after "_ENST" and remove dupes
     return list(
         set([gene.split("_ENST")[0] for gene in x if gene is not None])
     )
